@@ -20,6 +20,7 @@ extensions = [
         '_ext.show_nodes',
         'autoclasstoc',
         'sphinx.ext.autodoc',
+        'sphinx.ext.autosectionlabel',
         'sphinx.ext.autosummary',
         'sphinx.ext.viewcode',
         'sphinx.ext.intersphinx',
@@ -33,6 +34,10 @@ intersphinx_mapping = {
 autodoc_default_options = {
         'exclude-members': '__weakref__,__dict__,__module__',
 }
+autosummary_generate = True
 pygments_style = 'sphinx'
 html_theme = 'sphinx_rtd_theme'
-htmlhelp_basename = 'autoclasstocdoc'
+
+def setup(app):
+    app.add_css_file('css/autoclasstoc.css')
+
